==> ejc-probid-api-3.0.0-20220720.022701-23-sources.jar: com/ejianc/business/bid/vo/BusinessRecordVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 商机更新记录
 * 
 * @author generator
 * 
 */
public class BusinessRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long businessId; // 父表id
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date updateDate; // 更新日期

    private Long updateUserId; // 更新人id
    private String updateUserName; // 更新人
    private String recordProjectStatus; // 项目状态
    private String memo; // 更新内容
    

    public Long getBusinessId() {
        return businessId;
    }

    public void setBusinessId(Long businessId) {
        this.businessId = businessId;
    }
    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }
    public Long getUpdateUserId() {
        return updateUserId;
    }
    @ReferDeserialTransfer
    public void setUpdateUserId(Long updateUserId) {
        this.updateUserId = updateUserId;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRecordProjectStatus() {
        return recordProjectStatus;
    }

    public void setRecordProjectStatus(String recordProjectStatus) {
        this.recordProjectStatus = recordProjectStatus;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-probid-api-3.0.0-20220721.080654-33-sources.jar: com/ejianc/business/bid/vo/BusinessRecordVO.java <==
package com.ejianc.business.bid.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 商机更新记录
 * 
 * @author generator
 * 
 */
public class BusinessRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long businessId; // 父表id
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date updateDate; // 更新日期

    private Long updateUserId; // 更新人id
    private String updateUserName; // 更新人
    private String recordProjectStatus; // 项目状态
    private String operation; // 操作

    private String memo; // 更新内容

    public String getOperation() {
        return operation;
    }

    public void setOperation(String operation) {
        this.operation = operation;
    }

    public Long getBusinessId() {
        return businessId;
    }

    public void setBusinessId(Long businessId) {
        this.businessId = businessId;
    }
    public Date getUpdateDate() {
        return updateDate;
    }

    public void setUpdateDate(Date updateDate) {
        this.updateDate = updateDate;
    }
    public Long getUpdateUserId() {
        return updateUserId;
    }
    @ReferDeserialTransfer
    public void setUpdateUserId(Long updateUserId) {
        this.updateUserId = updateUserId;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRecordProjectStatus() {
        return recordProjectStatus;
    }

    public void setRecordProjectStatus(String recordProjectStatus) {
        this.recordProjectStatus = recordProjectStatus;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
